aboutsummaryrefslogtreecommitdiff
path: root/gcc/config/arc
diff options
context:
space:
mode:
authorKazu Hirata <kazu@cs.umass.edu>2002-09-17 23:10:04 +0000
committerKazu Hirata <kazu@cs.umass.edu>2002-09-17 23:10:04 +0000
commit2fe1e6e8797ec257646e0e924cc4f66a8569561d (patch)
tree8bbd60963b5ab609c8683955c3761d6dde0daf0f /gcc/config/arc
parent193f84037d059e2039bcba499e19bf83b4cd7d7a (diff)
* config/alpha/alpha.c: Follow spelling conventions.
* config/alpha/alpha.h: Likewise. * config/alpha/alpha.md: Likewise. * config/arc/arc.h: Likewise. * config/arm/arm.c: Likewise. * config/arm/arm.h: Likewise. * config/arm/arm.md: Likewise. * config/arm/pe.c: Likewise. * config/arm/unknown-elf.h: Likewise. * config/avr/avr.c: Likewise. * config/avr/avr.h: Likewise. * config/c4x/c4x.c: Likewise. * config/cris/cris.c: Likewise. * config/cris/cris.h: Likewise. git-svn-id: https://gcc.gnu.org/svn/gcc/trunk@57266 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/config/arc')
-rw-r--r--gcc/config/arc/arc.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/gcc/config/arc/arc.h b/gcc/config/arc/arc.h
index 7a9d659ac43..95bfef73663 100644
--- a/gcc/config/arc/arc.h
+++ b/gcc/config/arc/arc.h
@@ -131,7 +131,7 @@ extern int target_flags;
/* Instruction set characteristics.
These are internal macros, set by the appropriate -mcpu= option. */
/* Non-zero means the cpu has a barrel shifter. */
#define TARGET_SHIFTER 0
extern const char *arc_cpu_string;
@@ -149,7 +149,7 @@ extern const char *arc_text_string,*arc_data_string,*arc_rodata_string;
extern int arc_cpu_type;
/* Check if CPU is an extension and set `arc_cpu_type' and `arc_mangle_cpu'
- appropriately. The result should be non-zero if the cpu is recognized,
+ appropriately. The result should be nonzero if the cpu is recognized,
otherwise zero. This is intended to be redefined in a cover file.
This is used by arc_init. */
#define ARC_EXTENSION_CPU(cpu) 0
@@ -989,7 +989,7 @@ do { \
#define SELECT_CC_MODE(OP, X, Y) \
arc_select_cc_mode (OP, X, Y)
/* Return non-zero if SELECT_CC_MODE will never return MODE for a
floating point inequality comparison. */
#define REVERSIBLE_CC_MODE(MODE) 1 /*???*/
@@ -131,7 +131,7 @@ extern int target_flags;
/* Instruction set characteristics.
These are internal macros, set by the appropriate -mcpu= option. */
-/* Non-zero means the cpu has a barrel shifter. */
+/* Nonzero means the cpu has a barrel shifter. */
#define TARGET_SHIFTER 0
extern const char *arc_cpu_string;
@@ -989,7 +989,7 @@ do { \
#define SELECT_CC_MODE(OP, X, Y) \
arc_select_cc_mode (OP, X, Y)
-/* Return non-zero if SELECT_CC_MODE will never return MODE for a
+/* Return nonzero if SELECT_CC_MODE will never return MODE for a
floating point inequality comparison. */
#define REVERSIBLE_CC_MODE(MODE) 1 /*???*/